summaryrefslogtreecommitdiff
path: root/doc/packet-PROTOABBREV.c
diff options
context:
space:
mode:
authorMichael Mann <mmann78@netscape.net>2015-12-08 21:10:31 -0500
committerMichael Mann <mmann78@netscape.net>2015-12-09 03:12:44 +0000
commit12f6311b20658aba7b1b441b0260f88401cd06fb (patch)
tree4698afd8c2cadabb0f38a85a5ea0525560a7b52d /doc/packet-PROTOABBREV.c
parenta391a70b3b05c3a3c95bcb9020b37adb6c0af010 (diff)
downloadwireshark-12f6311b20658aba7b1b441b0260f88401cd06fb.tar.gz
"new" dissector API -> dissector API for docs/examples
Change-Id: If862aadbd483933782d5979a3c0be2cb3c08a480 Reviewed-on: https://code.wireshark.org/review/12481 Reviewed-by: Michael Mann <mmann78@netscape.net>
Diffstat (limited to 'doc/packet-PROTOABBREV.c')
-rw-r--r--doc/packet-PROTOABBREV.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/doc/packet-PROTOABBREV.c b/doc/packet-PROTOABBREV.c
index 3334ad156a..eee649d712 100644
--- a/doc/packet-PROTOABBREV.c
+++ b/doc/packet-PROTOABBREV.c
@@ -301,11 +301,11 @@ proto_reg_handoff_PROTOABBREV(void)
static int current_port;
if (!initialized) {
/* Use new_create_dissector_handle() to indicate that
* dissect_PROTOABBREV() returns the number of bytes it dissected (or 0
* if it thinks the packet does not belong to PROTONAME).
*/
- PROTOABBREV_handle = new_create_dissector_handle(dissect_PROTOABBREV,
+ PROTOABBREV_handle = create_dissector_handle(dissect_PROTOABBREV,
proto_PROTOABBREV);
initialized = TRUE;
@@ -336,11 +336,11 @@ proto_reg_handoff_PROTOABBREV(void)
{
dissector_handle_t PROTOABBREV_handle;
/* Use new_create_dissector_handle() to indicate that dissect_PROTOABBREV()
* returns the number of bytes it dissected (or 0 if it thinks the packet
* does not belong to PROTONAME).
*/
- PROTOABBREV_handle = new_create_dissector_handle(dissect_PROTOABBREV,
+ PROTOABBREV_handle = create_dissector_handle(dissect_PROTOABBREV,
proto_PROTOABBREV);
dissector_add_uint("tcp.port", PROTOABBREV_TCP_PORT, PROTOABBREV_handle);
}
@@ -301,11 +301,11 @@ proto_reg_handoff_PROTOABBREV(void)
static int current_port;
if (!initialized) {
- /* Use new_create_dissector_handle() to indicate that
+ /* Use create_dissector_handle() to indicate that
* dissect_PROTOABBREV() returns the number of bytes it dissected (or 0
* if it thinks the packet does not belong to PROTONAME).
@@ -336,11 +336,11 @@ proto_reg_handoff_PROTOABBREV(void)
{
dissector_handle_t PROTOABBREV_handle;
- /* Use new_create_dissector_handle() to indicate that dissect_PROTOABBREV()
+ /* Use create_dissector_handle() to indicate that dissect_PROTOABBREV()
* returns the number of bytes it dissected (or 0 if it thinks the packet
* does not belong to PROTONAME).